@@ -14,6 +14,8 @@ class MuviBase:
             response = {}
         if message:
             response['message'] = message
+        if 'status' not in response:
+            response['status'] = status
         response['processor'] = self.processor
         return {
             'status': status,
