@@ -29,5 +29,5 @@ class CardToken(MuviBase):
         self.headers['apikey'] = self.private_key
         response = r.json()
         if r.status_code > 299:
-            return self.error(response, message=response['error_type'], status=r.status_code)
-        return self.ok(response, status=r.status_code)
+            return self.error(response=response, message=response['error_type'], status=r.status_code)
+        return self.ok(response=response, status=r.status_code)
