@@ -8,15 +8,10 @@ from .Refund import Refund
 
 class MercadoPagoSDK:
     def __init__(self, merchant: dict, marketplace: bool = False):
-        active = True
-        if 'credentials' in merchant and 'mercadopago' in merchant['credentials'] and not marketplace:
-            active = merchant['credentials']['mercadopago']['active']
-            access_token = merchant['credentials']['mercadopago']['access_token'] if active else None
-        elif 'credentials' in merchant and 'mp_marketplace' in merchant['credentials'] and marketplace:
-            active = 'mp_marketplace' in merchant['credentials'] and \
-                     ('active' not in merchant['credentials']['mp_marketplace'] or
-                      merchant['credentials']['mp_marketplace']['active'])
-            access_token = merchant['credentials']['mp_marketplace']['access_token'] if active else None
+        mercadopago_model = 'mp_marketplace' if marketplace else 'mercadopago'
+
+        active = merchant['credentials'][mercadopago_model]['active']
+        access_token = merchant['credentials'][mercadopago_model]['access_token'] if active else None
 
         self.sdk = mercadopago.SDK(access_token) if active else None
         self.merchant_id = merchant['_id']
