@@ -45,6 +45,11 @@ def _format(response):
     if response['payment_method_id'] in card_brand_map:
         response['payment_method_id'] = card_brand_map[response['payment_method_id']]
 
+    fee_details = [{'type': d['type'], 'amount': d['amount']} for d in response['fee_details']]
+    for f in [{'type': d['name'], 'amount': d['amounts']['original']} for d in response['charges_details']]:
+        if f not in fee_details:
+            fee_details.append(f)
+
     return {
         'id': response['id'],
         'transaction_amount': response['transaction_amount'],
@@ -52,11 +57,15 @@ def _format(response):
         'status': response['status'],
         'status_detail': response['status_detail'],
         'card': _format_card(response),
-        'payment_day': parse_date(response['date_created']),    # es igual a date_created
+        'payment_day': parse_date(response['date_created']),
         'statement_descriptor': response['statement_descriptor'],
         'payment_method_id': response['payment_method_id'],
         'payment_method': response['payment_method'],
-        'installments': response['installments']
+        'installments': response['installments'],
+        'transaction_details': {
+            'fee_details': fee_details,
+            'net_received_amount': response['transaction_details']['net_received_amount']
+        }
     }
 
 
